@@ -1,9 +1,9 @@
 package Pod::Weaver::Plugin::Sort::Sub;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-12-15'; # DATE
+our $DATE = '2019-12-17'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sort-Sub'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -105,7 +105,10 @@ sub weave_section {
 
                     push @pod, "$sch->[0].\n\n";
 
-                    push @pod, $argspec->{summary}, ".\n\n" if defined $argspec->{summary};
+                    if (defined $argspec->{summary}) {
+                        require String::PodQuote;
+                        push @pod, String::PodQuote::pod_quote($argspec->{summary}), ".\n\n";
+                    }
 
                     if ($argspec->{description}) {
                         require Markdown::To::POD;
@@ -157,7 +160,7 @@ Pod::Weaver::Plugin::Sort::Sub - Plugin to use when building Sort::Sub::* module
 
 =head1 VERSION
 
-This document describes version 0.004 of Pod::Weaver::Plugin::Sort::Sub (from Perl distribution Pod-Weaver-Plugin-Sort-Sub), released on 2019-12-15.
+This document describes version 0.005 of Pod::Weaver::Plugin::Sort::Sub (from Perl distribution Pod-Weaver-Plugin-Sort-Sub), released on 2019-12-17.
 
 =head1 SYNOPSIS
 
